package com.sky.ioc.controller.organzation;

import com.sky.ioc.entity.domain.organization.Company;
import com.sky.ioc.service.organization.CompanyService;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "组织管理--公司")
@Slf4j
@RestController
@RequestMapping("/organzation")
public class CompanyController {

    @Autowired
    CompanyService companyService;

    @ApiOperation("获取公司详情")
    @GetMapping(value = "/company")
    public ReturnMsg getCompany(@RequestParam(name = "company_id") Integer company_id) {
        return companyService.getCompany(company_id);
    }

    @ApiOperation("获取所有公司列表")
    @GetMapping(value = "/all_company")
    public ReturnMsg getAllCompany() {
        return companyService.getAllCompany();
    }

    @ApiOperation("获取公司列表")
    @GetMapping(value = "/company_list")
    public ReturnMsg getCompanyList(@RequestParam(name = "page",defaultValue = "1") Integer page,
                                    @RequestParam(name = "page_size",defaultValue = "20") Integer page_size) {
        return companyService.getAllCompany(page,page_size);
    }

    @ApiOperation("公司查询")
    @GetMapping(value = "/company_search")
    public ReturnMsg searchCompanyList(@RequestParam(name = "name")String name) {
        return companyService.searchCompany(name);
    }

    @ApiOperation("添加公司")
    @PostMapping(value = "/company")
    public ReturnMsg addCompany(Company company) {
        return companyService.addCompany(company);
    }

    @ApiOperation("更新公司")
    @PutMapping(value = "/company")
    public ReturnMsg editCompany(Company company) {
        return companyService.editCompany(company);
    }

    @ApiOperation("删除公司")
    @DeleteMapping(value = "/company")
    public ReturnMsg delCompany(@RequestParam(name = "company_id") Integer company_id) {
        return companyService.deleteCompany(company_id);
    }

}
