package com.sky.ioc.controller.user;

import com.sky.ioc.entity.domain.system.Users;
import com.sky.ioc.service.user.UserService;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

@Api(tags = "系统--用户管理")
@Slf4j
@RestController
@RequestMapping("/users")
public class UserController {

    @Autowired
    private UserService userService;

    @ApiOperation("添加用户")
    @PostMapping("/user")
    public ReturnMsg addUser(Users users) {
        return userService.addUser(users);
    }

    @ApiOperation("更新用户详情")
    @PutMapping("/user")
    public ReturnMsg updUser(Users users) {
        return userService.updUser(users);
    }

    @ApiOperation("查看用户详情")
    @GetMapping("/user")
    public ReturnMsg getUserDetail(@RequestParam String id) {
        return userService.getUserDetail(id);
    }

    @ApiOperation("删除用户")
    @DeleteMapping("/user")
    public ReturnMsg delUser(@RequestParam String id) {
        return userService.deleteUserById(id);
    }

    @ApiOperation("批量删除用户")
    @DeleteMapping("/bacth_delete_user")
    public ReturnMsg batchDelUser(@RequestParam String user_id) {
        return userService.deleteUserById(user_id);
    }

    @ApiOperation("获取用户列表")
    @GetMapping("/user_list")
    public ReturnMsg getUserList(@RequestParam(required = false) String status, @RequestParam(required = false) String filter,
                                 @RequestParam(required = false) String page, @RequestParam(required = false) String page_size) {
        return userService.getUserList(status, filter, page, page_size);
    }

    @ApiOperation("修改用户状态")
    @PutMapping("/user_status")
    public ReturnMsg modifyStatus(@RequestParam String id, @RequestParam String status) {
        return userService.updateUserStatus(id, status);
    }

    @ApiOperation("批量修改用户状态")
    @PutMapping("/batch_modify_user_status")
    public ReturnMsg batchModifyStatus(@RequestParam String users_id , @RequestParam String status) {
        return userService.batchModifyStatus(users_id , status);
    }

    @ApiOperation("批量修改用户角色")
    @PutMapping("/batch_modify_user_role")
    public ReturnMsg batchModifyUserRole(@RequestParam String users_id , @RequestParam String role_id) {
        return userService.batchModifyUserRole(users_id , role_id);
    }

    @ApiOperation("导出用户数据")
    @GetMapping("/export_data")
    public void exportData(HttpServletResponse response) {
        userService.exportData(response);
    }



}
