package com.sky.ioc.service.information.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.sky.ioc.entity.domain.information.FloorConfiguration;
import com.sky.ioc.entity.domain.information.FloorConfigurationHistory;
import com.sky.ioc.mapper.information.FloorConfigurationHistoryMapper;
import com.sky.ioc.mapper.information.FloorConfigurationMapper;
import com.sky.ioc.service.information.FloorConfigurationService;
import com.sky.ioc.tool.ReturnMsg;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class FloorConfigurationServiceImpl implements FloorConfigurationService {

    @Autowired
    FloorConfigurationMapper floorConfigurationMapper;

    @Autowired
    FloorConfigurationHistoryMapper floorConfigurationHistoryMapper;

    @Override
    public ReturnMsg getById(Integer id) {
        FloorConfiguration floorConfiguration = floorConfigurationMapper.selectById(id);
        return ReturnMsg.ok(floorConfiguration);
    }

    @Override
    public ReturnMsg delById(Integer id) {
        return ReturnMsg.ok(floorConfigurationMapper.deleteById(id));
    }

    @Override
    public ReturnMsg add(FloorConfiguration floorConfiguration) {
        if(StringUtils.isNotBlank(floorConfiguration.getName())){
            floorConfigurationMapper.insert(floorConfiguration);
            //添加历史记录
            FloorConfigurationHistory floorConfigurationHistory = new FloorConfigurationHistory();
            floorConfigurationHistory.setFloor_configuration(floorConfiguration.getId()+"");
            String res = "[{'time': "+new Date() +", 'url': "+floorConfiguration.getAttachment()+", 'account': }]";
            floorConfigurationHistory.setUrl(res);
            floorConfigurationHistoryMapper.insert(floorConfigurationHistory);
            return ReturnMsg.ok();
        }else{
            return ReturnMsg.fail("配置名不能为空");
        }
    }

    @Override
    public ReturnMsg edit(FloorConfiguration floorConfiguration) {
        if(StringUtils.isNotBlank(floorConfiguration.getName())){
            floorConfigurationMapper.updateById(floorConfiguration);
            //添加历史记录
            FloorConfigurationHistory floorConfigurationHistory = floorConfigurationHistoryMapper
                    .selectOne(new LambdaQueryWrapper<FloorConfigurationHistory>().eq(FloorConfigurationHistory::getFloor_configuration,floorConfiguration.getId()));
            String url = floorConfigurationHistory.getUrl();
            JSONArray array = JSONArray.parseArray(url);
            JSONObject json = new JSONObject();
            json.put("time",new Date()+"");
            json.put("url",floorConfiguration.getAttachment());
            json.put("account",floorConfiguration.getAccount());
            array.add(json);
            floorConfigurationHistory.setUrl(array.toJSONString());
            return ReturnMsg.ok();
        }else{
            return ReturnMsg.fail("配置名不能为空");
        }
    }

    @Override
    public List<FloorConfiguration> getList() {
        return floorConfigurationMapper.selectList(null);
    }
}
